#include <iostream>
#include <cstdlib>
#include <cstdio>
#include <vector>
#include <ctime>
#include <cmath>

#define MAX_SHAPE_VOLUME 40
#define MIN_COORD -1000000
#define MAX_COORD 1000000

#define MY_EPSILON 0.000001

using namespace std;

class Vertex
{
    public:
    double x, y;
    Vertex (double x=0, double y=0)
    {
        this->x = x;
        this->y = y;
    }

    Vertex operator * (const double & coef)
    {
        return Vertex (this->x * coef, this->y * coef);
    }

    Vertex operator / (const double & coef)
    {
        return Vertex (this->x / coef, this->y / coef);
    }

    Vertex operator + (const Vertex & v)
    {
        return Vertex (this->x + v.x, this->y + v.y);
    }

    Vertex operator - (const Vertex & v)
    {
        return Vertex (this->x - v.x, this->y - v.y);
    }

    bool operator == (const Vertex & v)
    {
        return this->x == v.x && this->y == v.y;
    }

    bool operator != (const Vertex & v)
    {
        return ! ((*this) == v);
    }
};

double CrossProduct (Vertex a, Vertex b)
{
    return (a.x * b.y) - (a.y * b.x);
}

double DotProduct (Vertex a, Vertex b)
{
    return (a.x * b.x) + (a.y * b.y);
}

bool VertexInSegment (Vertex v, Vertex segA, Vertex segB)
{
    Vertex AV = v-segA;
    Vertex BV = v-segB;
    if (fabs(CrossProduct(AV, BV)) < MY_EPSILON && DotProduct(AV, BV) < MY_EPSILON)
    {
        return true;
    }
    return false;
}

bool SegmentsIntersect (Vertex a, Vertex b, Vertex c, Vertex d)
{
    double A1 = b.y - a.y;
    double B1 = a.x - b.x;
    double C1 = A1 * a.x + B1 * a.y;

    double A2 = d.y - c.y;
    double B2 = c.x - d.x;
    double C2 = A2 * c.x + B2 * c.y;

    double det = A1 * B2 - A2 * B1;
    if (fabs(det) < MY_EPSILON)
    {
        if (VertexInSegment(c, a, b) || VertexInSegment(d, a, b) ||
            VertexInSegment(a, c, d) || VertexInSegment(b, c, d))
        {
            return true;
        }
    }
    else
    {
        Vertex lineIntersection = Vertex ((B2*C1 - B1*C2)/det, (A1*C2 - A2*C1)/det);
        if (VertexInSegment(lineIntersection, a, b) &&
            VertexInSegment(lineIntersection, c, d))
            {
                return true;
            }
    }
    return false;
}

class Target
{
  public:
  bool isHit;

  vector <Vertex> outline;

  Target ()
  {
      this->isHit = false;

      this->outline = vector<Vertex>();
  }

  Target (vector <Vertex> outline)
  {
      this->isHit = false;
      this->outline = outline;
  }

  Target * GetTranslated (Vertex translation)
  {
      int outlineSize = this->outline.size();
      vector <Vertex> vertices (outlineSize);
      for (int i=0; i<outlineSize; i++)
      {
          vertices[i] = this->outline[i] + translation;
      }
      return new Target (vertices);
  }

  bool Contains (Vertex v)
  {
      if (this->IsOutlineVertex (v))
      {
          return true;
      }

      int outlineSize = this->outline.size();
      Vertex outlineCurrent = this->outline[outlineSize -1];
      Vertex outlineNext = this->outline[0];
      double initialAngleDirection = CrossProduct(outlineNext - outlineCurrent, v - outlineCurrent);

      if (fabs(initialAngleDirection) < MY_EPSILON)
      {
          if (DotProduct(outlineCurrent - v, outlineNext - v) > MY_EPSILON)
          {
              return false;
          }
      }

      for (int i=0; i<outlineSize -1; i++)
      {
          outlineCurrent = this->outline[i];
          outlineNext = this->outline[i+1];
          double angleDirection = CrossProduct(outlineNext - outlineCurrent, v - outlineCurrent);

          if (angleDirection * initialAngleDirection < MY_EPSILON) //angle changed direction
          {
              return false;
          }
      }

      return true;
  }

  bool IsOutlineVertex (Vertex v)
  {
      int outlineSize = this->outline.size();
      for (int i=0; i<outlineSize; i++)
      {
          if (this->outline[i] == v)
          {
              return true;
          }
      }
      return false;
  }
};

class NodeAABB
{
    private:
    Vertex min, max;
    Vertex lowerLeft, upperLeft, lowerRight, upperRight;

    public:
    vector <Target*> contents;
    NodeAABB * parent;
    NodeAABB * leftSubBox, * rightSubBox;

    NodeAABB ()
    {
        this->parent = NULL;
        this->leftSubBox = NULL;
        this->rightSubBox = NULL;
        this->min = Vertex();
        this->max = Vertex();
        this->contents = vector <Target*>();
    }

    NodeAABB (Vertex min, Vertex max, vector <Target*> contentCandidates, bool xSplit=true, double minVolume = MY_EPSILON)
    {
        this->parent = NULL;
        this->leftSubBox = NULL;
        this->rightSubBox = NULL;

        this->min = min;
        this->max = max;

        this->lowerLeft = min;
        this->upperLeft = Vertex (min.x, max.y);
        this->lowerRight = Vertex (max.x, min.y);
        this->upperRight = max;

        this->TryAdd (contentCandidates);

        if (this->contents.size() > 0 && this->GetVolume()/2 >= minVolume)
        {
            this->CreateSplit(xSplit, minVolume);
        }
    }

    bool Contains (Vertex & v)
    {
        return
        (v.x >= min.x && v.x <= max.x) &&
        (v.y >= min.y && v.y <= max.y);
    }

    bool Contains (Target * t)
    {
        int tOutlineSize = t->outline.size();

        for (int i=0; i<tOutlineSize; i++)
        {
            if (this->Contains(t->outline[i]))
            {
                return true;
            }
        }
        if (
            t->Contains (this->lowerLeft) || t->Contains(this->lowerRight) ||
            t->Contains (this->upperLeft) || t->Contains(this->upperRight)
            )
            {
                return true;
            }

        Vertex tSegmentEnd = t->outline[tOutlineSize];
        Vertex tSegmentBegin = t->outline[0];

        if (SegmentsIntersect(this->lowerLeft, this->lowerRight, tSegmentEnd, tSegmentBegin) ||
            SegmentsIntersect(this->lowerRight, this->upperRight, tSegmentEnd, tSegmentBegin) ||
            SegmentsIntersect(this->upperRight, this->upperLeft, tSegmentEnd, tSegmentBegin) ||
            SegmentsIntersect(this->upperLeft, this->lowerLeft, tSegmentEnd, tSegmentBegin)
            )
            {
                return true;
            }
        for (int i=0; i<tOutlineSize-1; i++)
        {
            tSegmentBegin = t->outline[i];
            tSegmentEnd = t->outline[i+1];
            if (
            SegmentsIntersect(this->lowerLeft, this->lowerRight, tSegmentEnd, tSegmentBegin) ||
            SegmentsIntersect(this->lowerRight, this->upperRight, tSegmentEnd, tSegmentBegin) ||
            SegmentsIntersect(this->upperRight, this->upperLeft, tSegmentEnd, tSegmentBegin) ||
            SegmentsIntersect(this->upperLeft, this->lowerLeft, tSegmentEnd, tSegmentBegin)
            )
            {
                return true;
            }
        }

        return false;
    }

    void TryAdd (vector <Target*> candidates)
    {
        int candidatesSize = candidates.size();
        for (int i=0; i<candidatesSize; i++)
        {
            if (this->Contains (candidates[i]))
            {
                this->contents.push_back (candidates[i]);;
            }
        }
    }

    double GetVolume ()
    {
        return (this->max.x - this->min.x) * (this->max.y - this->min.y);
    }

    NodeAABB * GetMinContaining (Vertex v)
    {
        if (this->leftSubBox != NULL && this->rightSubBox != NULL)
        {
            if (this->leftSubBox->Contains (v))
            {
                return this->leftSubBox->GetMinContaining(v);
            }
            else
            {
                return this->rightSubBox->GetMinContaining(v);
            }
        }
        else
        {
            if (leftSubBox == NULL && rightSubBox != NULL)
            {
                return rightSubBox->GetMinContaining (v);
            }
            if (rightSubBox == NULL && leftSubBox != NULL)
            {
                return leftSubBox->GetMinContaining (v);
            }
        }
        return this;
    }

    private:

    void CreateSplit (bool xSplit, double minVolume)
    {
        if (xSplit)
        {
            this->CreateXSplit (minVolume);
        }
        else
        {
            this->CreateYSplit (minVolume);
        }
    }

    void CreateXSplit (double minVolume)
    {
        double xCenter = this->min.x + ((this->max.x - this->min.x)/2);
        double yTop = this->max.y;
        double yBottom = this->min.y;
        Vertex splitCenterMin = Vertex (xCenter, yBottom);
        Vertex splitCenterMax = Vertex (xCenter, yTop);

        this->leftSubBox = new NodeAABB (this->min, splitCenterMax, this->contents, false, minVolume);
        this->leftSubBox->parent = this;
        this->rightSubBox = new NodeAABB (splitCenterMin, this->max, this->contents, false, minVolume);
        this->rightSubBox->parent = this;
    }

    void CreateYSplit (double minVolume)
    {
        double yCenter = this->min.y + ((this->max.y - this->min.y)/2);
        double xRight = this->max.x;
        double xLeft = this->min.x;
        Vertex splitCenterMin = Vertex (xLeft, yCenter);
        Vertex splitCenterMax = Vertex (xRight, yCenter);

        this->leftSubBox = new NodeAABB (this->min, splitCenterMax, this->contents, true, minVolume);
        this->leftSubBox->parent = this;
        this->rightSubBox = new NodeAABB (splitCenterMin, this->max, this->contents, true, minVolume);
        this->rightSubBox->parent = this;
    }
};

class BSPTree
{
    public:
    NodeAABB * root;

    BSPTree (vector <Target*> & targetsToCover, double minTreeNodeVolume = MY_EPSILON)
    {
        Vertex min = Vertex (MAX_COORD, MAX_COORD),
            max = Vertex (MIN_COORD, MIN_COORD);

        int targetsToCoverSize = targetsToCover.size();
        for (int targInd=0; targInd<targetsToCoverSize; targInd++)
        {
            int outlineSize = targetsToCover[targInd]->outline.size();
            for (int targVertInd = 0; targVertInd < outlineSize; targVertInd++)
            {
                Vertex currentVertex = targetsToCover[targInd]->outline[targVertInd];

                if (min.x > currentVertex.x) {min.x = currentVertex.x;}
                if (min.y > currentVertex.y) {min.y = currentVertex.y;}

                if (max.x < currentVertex.x) {max.x = currentVertex.x;}
                if (max.y < currentVertex.y) {max.y = currentVertex.y;}
            }
        }
        root = new NodeAABB (min, max, targetsToCover, true, minTreeNodeVolume);
        root->parent = NULL;
    }

    NodeAABB * GetMinContaining (Vertex v)
    {
        return root->GetMinContaining (v);
    }
};

int GetNumHits (Vertex loc, BSPTree * bspTree)
{
    NodeAABB * node = bspTree->GetMinContaining (loc);
    int numHits = 0;

    int contentsSize = node->contents.size();
    for (int i=0; i<contentsSize; i++)
    {
        Target * currentTarget = node->contents[i];

        if ( ! currentTarget->isHit)
        {
            if (currentTarget->Contains (loc))
            {
                currentTarget->isHit = true;
                numHits++;
            }
        }
    }
    return numHits;
}

int ReadShotsAndGetHits (int shotsToRead, BSPTree * targetsTree)
{
    int hitCount = 0;
    Vertex shot;
    for (int i=0; i<shotsToRead; i++)
    {
        scanf ("%lf%lf", &shot.x, &shot.y);
        hitCount += GetNumHits (shot, targetsTree);
    }
    return hitCount;
}

int main ()
{
    unsigned long long ticksStart;
    ticksStart = clock();

    vector <Target*> targets;

    double maxShapeVolume = MAX_SHAPE_VOLUME;
    //scanf ("%lf", &maxShapeVolume);
    int numTargets, numShots;
    vector <Vertex> currentOutline;

    scanf ("%d%d", &numTargets, &numShots);

    for (int i=0; i<numTargets; i++)
    {
        currentOutline.clear();
        int currentOutlineSize;
        scanf ("%d", &currentOutlineSize);

        for (int j=0; j<currentOutlineSize; j++)
        {
            double outlineVertX, outlineVertY;
            Vertex outlineVert;
            scanf ("%lf%lf", &outlineVertX, &outlineVertY);

            outlineVert = Vertex (outlineVertX, outlineVertY);
            currentOutline.push_back (outlineVert);
        }
        targets.push_back (new Target (currentOutline));
    }

    BSPTree * targetsTree = new BSPTree (targets, maxShapeVolume);
    cout << ReadShotsAndGetHits(numShots, targetsTree) << endl;
    return 0;
}
